/**
 * Copyright (c) 2014-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.api.pref.exception;

import org.ow2.petals.cli.api.pref.PreferenceFileException;

/**
 * A property value is incorrect in the preference file.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class IncorrectPropertyValueException extends PreferenceFileException {
    
    private static final long serialVersionUID = -5541177484390541646L;

    public static final String MESSAGE_PATTERN = "The value '%s' for the property '%s' is incorrect.";

    /**
     * The name of the property having an incorrect value
     */
    private final String incorrectPropertyName;
    
    /**
     * The incorrect value
     */
    private final String incorrectValue;

    public IncorrectPropertyValueException(final String incorrectPropertyName, final String incorrectValue,
            final Throwable cause) {
        super(String.format(MESSAGE_PATTERN, incorrectValue, incorrectPropertyName), cause);
        this.incorrectPropertyName = incorrectPropertyName;
        this.incorrectValue = incorrectValue;
    }

    /**
     * @return The name of the property having the incorrect value
     */
    public String getIncorrectPropertyName() {
        return this.incorrectPropertyName;
    }

    /**
     * @return The incorrect value
     */
    public String getIncorrectValue() {
        return this.incorrectValue;
    }

}
